<?xml version='1.0'?>

<xsl:stylesheet xmlns:xsl      = 'http://www.w3.org/1999/XSL/Transform'
                xmlns:xsd      = 'http://www.w3.org/2001/XMLSchema'
                xmlns:soap     = 'http://schemas.xmlsoap.org/wsdl/soap/'
                xmlns:wsdl     = 'http://schemas.xmlsoap.org/wsdl/'
                xmlns:java     = 'http://xml.apache.org/xslt/java'
                xmlns:wf       = 'com.ibm.workflow.util.fdl.make.WSDL'
                xmlns:redirect = 'xalan://org.apache.xalan.lib.Redirect'
                extension-element-prefixes='redirect'
                version='1.0'>
<!--            xmlns:redirect = 'org.apache.xalan.xslt.extensions.Redirect' -->
<xsl:param name='generator'/>
<xsl:param name='package'/>
<xsl:param name='basedir'/>
<xsl:param name='output'/>

<xsl:output method='text'/>

<xsl:template match='text()'/>

<xsl:template match="/">
 <xsl:apply-templates select="wsdl:definitions/wsdl:portType"/>
</xsl:template>

<xsl:template match='wsdl:portType'>
 <xsl:variable name='fileName'  select='wf:getFileName(string(@name), $basedir, $package, "Proxy.java")'/>
 <xsl:variable name='className' select='concat(@name, "Proxy")'/>
 <redirect:write select='$fileName'>
 <xsl:text>// MQSeries Workflow SOAP Proxy class for WSDL portType '</xsl:text>
 <xsl:value-of select='@name'/>
 <xsl:text>'
// This file ("</xsl:text>
 <xsl:variable name='javaFile' select='java:java.io.File.new($fileName)'/>
 <xsl:variable name='absoluteFileName' select='java:getAbsolutePath($javaFile)'/>
 <xsl:value-of select='$absoluteFileName'/>
 <xsl:text>")
// was generated by </xsl:text>
 <xsl:value-of select='$generator'/>
 <xsl:text> on </xsl:text>
 <xsl:value-of select='java:java.util.Date.new()'/>
 <xsl:text>
// from WSDL file "</xsl:text>
 <xsl:value-of select='$output'/>
 <xsl:text>"</xsl:text>
 <xsl:if test='$package!=""'>
  <xsl:text>

package </xsl:text>
  <xsl:value-of select='$package'/>
  <xsl:text>;</xsl:text>
 </xsl:if>
 <xsl:text>

import java.net.*;
import java.util.*;
import org.apache.soap.*;
import org.apache.soap.encoding.*;
import org.apache.soap.rpc.*;
import org.apache.soap.util.xml.*;

public class </xsl:text>
 <xsl:value-of select='$className'/>
 <xsl:text>
{
  private Call call = new Call();
  private URL url = null;
  private String SOAPActionURI = "";

  private static final SOAPException NO_URL = new SOAPException(Constants.FAULT_CODE_CLIENT, "Must specifiy URL via </xsl:text>
 <xsl:value-of select='$className'/>
 <xsl:text>.setEndPoint(URL).");
 </xsl:text>
 <xsl:for-each select='wf:getClosure(@name)'>
  <xsl:text>
  private static final </xsl:text>
  <xsl:value-of select='./@name'/>
  <xsl:text>Deserializer ser_</xsl:text>
  <xsl:number value='position()'/>
  <xsl:text> = new </xsl:text>
  <xsl:value-of select='./@name'/>
  <xsl:text>Deserializer();</xsl:text>
 </xsl:for-each>
 <xsl:text>

   public </xsl:text>
 <xsl:value-of select='$className'/>
 <xsl:text>() throws MalformedURLException
  {
    call.setTargetObjectURI("urn:</xsl:text>
 <xsl:value-of select='wf:getUrn(@name)'/>
 <xsl:text>");
    call.setEncodingStyleURI(Constants.NS_URI_SOAP_ENC);
 </xsl:text>
 <xsl:for-each select='wf:getClosure(@name)'>
  <xsl:text>
    call.getSOAPMappingRegistry().mapTypes(Constants.NS_URI_SOAP_ENC,
                                           new QName("</xsl:text>
  <!-- <xsl:value-of select='//xsd:schema/@targetNamespace'/> -->
  <xsl:value-of select='./@namespace'/>
  <xsl:text>", "</xsl:text>  <xsl:value-of select='./@name'/>
  <xsl:text>"),
                                           </xsl:text>
  <xsl:value-of select='./@name'/>
  <xsl:text>.class, ser_</xsl:text>
  <xsl:number value='position()'/>
  <xsl:text>, ser_</xsl:text>
  <xsl:number value='position()'/>
  <xsl:text>);</xsl:text>
 </xsl:for-each>
 <xsl:text>
    this.url = new URL("</xsl:text>

 <xsl:variable name='portTypeName' select='@name'/>
 <xsl:variable name='bindingName' select='//wsdl:binding[@type=$portTypeName]/@name'/>
 <xsl:value-of select='//wsdl:port[@binding=$bindingName]/soap:address/@location'/>

 <xsl:text>");
    this.SOAPActionURI = "";
  }

  public synchronized void setEndPoint(URL url) { this.url = url; }
  public synchronized URL  getEndPoint()        { return url; }</xsl:text>
 <xsl:for-each select='./wsdl:operation'>
  <xsl:call-template name='proxyMethodDefinition'/>
 </xsl:for-each>
 <xsl:text>
}
 </xsl:text>
</redirect:write>
</xsl:template>

<xsl:template name='proxyMethodDefinition'>
<xsl:variable name='inMsg'  select='./wsdl:input/@message'/>
<xsl:variable name='outMsg' select='./wsdl:output/@message'/>
<xsl:variable name='param'  select='wf:getJavaType("", //wsdl:message[@name=$inMsg]/wsdl:part/@type, null)'/>
<xsl:variable name='return' select='wf:getJavaType("", //wsdl:message[@name=$outMsg]/wsdl:part/@type, null)'/>
 <xsl:text>

  public synchronized </xsl:text>
 <xsl:value-of select='$return'/>
 <xsl:text> </xsl:text>
 <xsl:value-of select='@name'/>
 <xsl:text>(</xsl:text>
 <xsl:if test='string($param)!="void"'>
  <xsl:value-of select='$param'/>
  <xsl:text> </xsl:text>
  <xsl:value-of select='$param'/>
 </xsl:if>
 <xsl:text>) throws SOAPException
  {
    if (url == null) throw NO_URL;

    call.setMethodName("</xsl:text>
 <xsl:value-of select='@name'/>
 <xsl:text>");

    Vector params = </xsl:text>
 <xsl:choose>
  <xsl:when test='string($param)!="void"'>
   <xsl:text>new Vector();

    Parameter </xsl:text>
   <xsl:value-of select='$param'/>
   <xsl:text>Param = new Parameter("</xsl:text>
   <xsl:value-of select='$param'/>
   <xsl:text>", </xsl:text>
   <xsl:value-of select='$param'/>
   <xsl:text>.class, </xsl:text>
   <xsl:value-of select='$param'/>
   <xsl:text>, null);

    params.addElement(</xsl:text>
   <xsl:value-of select='$param'/>
   <xsl:text>Param);</xsl:text>
  </xsl:when>
  <xsl:otherwise>
   <xsl:text>null;</xsl:text>
  </xsl:otherwise>
 </xsl:choose>
 <xsl:text>

    call.setParams(params);

    Response resp = call.invoke(url, SOAPActionURI);

    if (resp.generatedFault()) throw new SOAPException(resp.getFault().getFaultCode(), resp.getFault().getFaultString());</xsl:text>
 <xsl:if test='string($return)!="void"'>
  <xsl:text>

    return (</xsl:text>
  <xsl:value-of select='$return'/>
  <xsl:text>)resp.getReturnValue().getValue();</xsl:text>
 </xsl:if>
 <xsl:text>
  }</xsl:text>
</xsl:template>

</xsl:stylesheet>
