<?xml version='1.0'?>

<xsl:stylesheet xmlns:xsl      = 'http://www.w3.org/1999/XSL/Transform'
                xmlns:xsd      = 'http://www.w3.org/2001/XMLSchema'
                xmlns:soap     = 'http://schemas.xmlsoap.org/wsdl/soap/'
                xmlns:wsdl     = 'http://schemas.xmlsoap.org/wsdl/'
                xmlns:java     = 'http://xml.apache.org/xslt/java'
                xmlns:wf       = 'com.ibm.workflow.util.fdl.make.WSDL'
                xmlns:redirect = 'org.apache.xalan.xslt.extensions.Redirect'
                extension-element-prefixes='redirect'
                version='1.0'>

<xsl:param name='generator'/>
<xsl:param name='package'/>
<xsl:param name='basedir'/>
<xsl:param name='output'/>
<xsl:param name='ddpostfix'/>
<xsl:param name='sns'/>

<xsl:output method='text'/>

<xsl:template match='text()'/>

<xsl:template match="/">
 <xsl:apply-templates select='wsdl:definitions/wsdl:service'/>
</xsl:template>

<xsl:template match='wsdl:service'>
 <xsl:variable name='fileName' select='wf:getFileName(string(@name), $basedir, "", "DeploymentScript.bat")'/>
 <redirect:write select='$fileName'>
 <xsl:text>: MQSeries Workflow deployment script for WSDL service '</xsl:text>
 <xsl:value-of select='@name'/>
 <xsl:text>'
: This file ("</xsl:text>
 <xsl:variable name='javaFile' select='java:java.io.File.new($fileName)'/>
 <xsl:variable name='absoluteFileName' select='java:getAbsolutePath($javaFile)'/>
 <xsl:value-of select='$absoluteFileName'/>
 <xsl:text>")
: was generated by </xsl:text>
 <xsl:value-of select='$generator'/>
 <xsl:text> on </xsl:text>
 <xsl:value-of select='java:java.util.Date.new()'/>
 <xsl:text>
: from WSDL file "</xsl:text>
 <xsl:value-of select='$output'/>
 <xsl:text>"

@echo off
@echo Compiling SOAP wrapper, serializer and proxies ...</xsl:text>
 <xsl:variable name='path' select='concat(translate($package, ".", "/"), "/")'/>
 <xsl:for-each select='//xsd:complexType[starts-with(@name, $sns)]'>
  <xsl:variable name='class' select='wf:globalName(@name)'/>
  <xsl:text>
javac -classpath .;%CLASSPATH% </xsl:text>
  <xsl:value-of select='$path'/>
  <xsl:value-of select='$class'/>
  <xsl:text>.java</xsl:text>
  <xsl:text> </xsl:text>
  <xsl:value-of select='$path'/>
  <xsl:value-of select='$class'/>
  <xsl:text>Deserializer.java</xsl:text>
 </xsl:for-each>
 <xsl:for-each select='//wsdl:portType'>
  <xsl:text>
javac -classpath .;%CLASSPATH% </xsl:text>
  <xsl:value-of select='$path'/>
  <xsl:value-of select='wf:globalName(@name)'/>
  <xsl:text>Proxy.java</xsl:text>
 </xsl:for-each>
 <xsl:text>
@echo Done.</xsl:text>
 <xsl:for-each select='wsdl:port'>
  <xsl:variable name='binding' select='@binding'/>
  <xsl:text>
@echo Deploying SOAP service '</xsl:text>
  <xsl:value-of select='//wsdl:binding[@name = $binding]/@type'/>
  <xsl:text>' ...
java org.apache.soap.server.ServiceManagerClient </xsl:text>
  <xsl:value-of select='soap:address/@location'/>
  <xsl:text> deploy </xsl:text>
  <xsl:value-of select='//wsdl:binding[@name = $binding]/@type'/>
  <xsl:value-of select='$ddpostfix'/>
  <xsl:text>.xml
@echo Done.</xsl:text>
 </xsl:for-each>
 </redirect:write>
</xsl:template>

</xsl:stylesheet>
