<?xml version='1.0'?>

<xsl:stylesheet xmlns:xsl      = 'http://www.w3.org/1999/XSL/Transform'
                xmlns:xsd      = 'http://www.w3.org/2001/XMLSchema'
                xmlns:java     = 'http://xml.apache.org/xslt/java'
                xmlns:wf       = 'com.ibm.workflow.util.fdl.make.WSDL'
                xmlns:redirect = 'xalan://org.apache.xalan.lib.Redirect'
                extension-element-prefixes='redirect'
                version='1.0'>
<!--         xmlns:redirect = 'org.apache.xalan.xslt.extensions.Redirect' -->

<xsl:param name='generator'/>
<xsl:param name='package'/>
<xsl:param name='basedir'/>
<xsl:param name='output'/>
<xsl:param name='sns'/>

<xsl:output method='text'/>

<xsl:template match='text()'/>

<xsl:template match='/'>
 <xsl:apply-templates/>
</xsl:template>

<xsl:template match='xsd:schema'>
 <xsl:for-each select='xsd:complexType[starts-with(@name, $sns)]'>
  <xsl:variable name='typeName' select='wf:globalName(@name)'/>
  <xsl:variable name='fileName' select='wf:getFileName($typeName, $basedir, $package, "Deserializer.java")'/>
 <redirect:write select='$fileName'>
  <xsl:text>// MQSeries Workflow SOAP (De-)serializer for messages transporting '</xsl:text>
  <xsl:value-of select='$typeName'/>
  <xsl:text>' STRUCTUREs
// This file ("</xsl:text>
  <xsl:variable name='javaFile' select='java:java.io.File.new($fileName)'/>
  <xsl:variable name='absoluteFileName' select='java:getAbsolutePath($javaFile)'/>
  <xsl:value-of select='$absoluteFileName'/>
  <xsl:text>")
// was generated by </xsl:text>
  <xsl:value-of select='$generator'/>
  <xsl:text> on </xsl:text>
  <xsl:value-of select='java:java.util.Date.new()'/>
  <xsl:text>
// from WSDL file "</xsl:text>
  <xsl:value-of select='$output'/>
  <xsl:text>"</xsl:text>
  <xsl:if test='$package!=""'>
   <xsl:text>

package </xsl:text>
   <xsl:value-of select='$package'/>
   <xsl:text>;</xsl:text>
  </xsl:if>
  <xsl:text>

import java.io.*;
import org.w3c.dom.*;
import org.apache.soap.*;
import org.apache.soap.encoding.soapenc.*;
import org.apache.soap.rpc.*;
import org.apache.soap.util.*;
import org.apache.soap.util.xml.*;
import com.ibm.workflow.soap.provider.ArrayDeserializer;

public class </xsl:text>
  <xsl:value-of select='$typeName'/>
  <xsl:text>Deserializer implements Serializer, Deserializer
{
  public void marshall(String inScopeEncStyle, Class javaType, Object src, Object context, Writer sink,
                       NSStack nsStack, XMLJavaMappingRegistry xjmr, SOAPContext ctx)
  throws IllegalArgumentException, IOException
  {
    nsStack.pushScope();

    SoapEncUtils.generateStructureHeader(inScopeEncStyle, javaType, context, sink, nsStack, xjmr);

    sink.write(StringUtils.lineSeparator);

    </xsl:text>
  <xsl:value-of select='$package'/>
  <xsl:text>.</xsl:text>
  <xsl:value-of select='$typeName'/>
  <xsl:text> src2 = (</xsl:text>
  <xsl:value-of select='$package'/>
  <xsl:text>.</xsl:text>
  <xsl:value-of select='$typeName'/>
  <xsl:text>)src;

    Parameter param;
  </xsl:text>
  <xsl:for-each select='.//xsd:element'>
   <xsl:call-template name='serializeElement'/>
  </xsl:for-each>
  <xsl:text>
    sink.write("&lt;/" + context + '&gt;');

    nsStack.popScope();
  }

  public Bean unmarshall(String inScopeEncStyle, QName elementType, Node src, XMLJavaMappingRegistry xjmr, SOAPContext ctx)
  throws IllegalArgumentException
  {
    Element e = DOMUtils.getFirstChildElement((Element)src);

    </xsl:text>

  <xsl:value-of select='$package'/>
  <xsl:text>.</xsl:text>
  <xsl:value-of select='$typeName'/>
  <xsl:text> target;

    try
    {
      target = (</xsl:text>
  <xsl:value-of select='$package'/>
  <xsl:text>.</xsl:text>
  <xsl:value-of select='$typeName'/>
  <xsl:text>)</xsl:text>
  <xsl:value-of select='$package'/>
  <xsl:text>.</xsl:text>
  <xsl:value-of select='$typeName'/>
  <xsl:text>.class.newInstance();
    }
    catch (Exception xcpt) { throw new IllegalArgumentException("Problem instantiating bean: " + xcpt.getMessage()); }

    while (e != null)
    {
      String tagName = e.getTagName();
  </xsl:text>
  <xsl:for-each select='.//xsd:element'>
   <xsl:call-template name='deserializeElement'/>
  </xsl:for-each>
  <xsl:text>

      e = DOMUtils.getNextSiblingElement(e);
    }

    return new Bean(</xsl:text>
  <xsl:value-of select='$package'/>
  <xsl:text>.</xsl:text>
  <xsl:value-of select='$typeName'/>
  <xsl:text>.class, target);
  }

  private static final StringDeserializer stringDeser = new StringDeserializer();
  private static final LongDeserializer   longDeser   = new LongDeserializer  ();
  private static final DoubleDeserializer doubleDeser = new DoubleDeserializer();
  private static final Base64Serializer   binaryDeser = new Base64Serializer  ();
  private static final ArrayDeserializer  arrayDeser  = new ArrayDeserializer ();</xsl:text>
  <xsl:for-each select='wf:getComplex(.//xsd:element)'>
   <xsl:text>
  private static final </xsl:text>
   <xsl:value-of select='.'/>
   <xsl:text>Deserializer </xsl:text>
   <xsl:value-of select='.'/>
   <xsl:text>Deser = new </xsl:text>
   <xsl:value-of select='.'/>
   <xsl:text>Deserializer();</xsl:text>
  </xsl:for-each>
  <xsl:text>
}
  </xsl:text>
 </redirect:write> 
 </xsl:for-each>
</xsl:template>

<xsl:template name='serializeElement'>
 <xsl:variable name='javaType'  select='wf:getJavaType($package, @type, @maxOccurs)'/>
 <xsl:variable name='fieldName' select='concat("src2.", @name, "_Elem")'/>
 <xsl:text>
    param = new Parameter("</xsl:text>
 <xsl:value-of select='@name'/>
 <xsl:text>", </xsl:text>
 <xsl:value-of select='$javaType'/>
 <xsl:text>.class, </xsl:text>
 <xsl:value-of select="wf:convertToObject($javaType, $fieldName)"/>
 <xsl:text>, null);
    xjmr.marshall(inScopeEncStyle, Parameter.class, param, null, sink, nsStack, ctx);
    sink.write(StringUtils.lineSeparator);
 </xsl:text>
</xsl:template>

<xsl:template name='deserializeElement'>
 <xsl:variable name='javaType'   select='wf:getJavaType($package, @type, @maxOccurs)'/>
 <xsl:variable name='serializer' select='wf:getSerializer(@type, @maxOccurs)'/>
 <xsl:if test='position() = 1'>
 <xsl:text>
      </xsl:text>
 </xsl:if>
 <xsl:if test='position() != 1'>
 <xsl:text>
      else </xsl:text>
 </xsl:if>
 <xsl:text>if (tagName.equals("</xsl:text>
 <xsl:value-of select='@name'/>
 <xsl:text>"))
      {
        Bean b = </xsl:text>
 <xsl:value-of select='$serializer'/>
 <xsl:text>Deser.unmarshall(inScopeEncStyle, </xsl:text>
 <xsl:if test='$serializer = "array"'>
  <xsl:value-of select='wf:getQName($package, @type)'/>
 </xsl:if>
 <xsl:if test='$serializer != "array"'>
  <xsl:text>elementType</xsl:text>
 </xsl:if>
 <xsl:text>, e, xjmr, ctx);

        target.</xsl:text>
 <xsl:value-of select='@name'/>
 <xsl:text>_Elem = </xsl:text>
 <xsl:value-of select='wf:convertFromObject($javaType, "b.value")'/>
 <xsl:text>;</xsl:text>
 <xsl:if test='$serializer = "array"'>
  <xsl:text>

        do { e = DOMUtils.getNextSiblingElement(e); } while (e != null &amp;&amp; e.getTagName().equals(tagName)); continue;</xsl:text>
 </xsl:if>
 <xsl:text>
      }</xsl:text>
</xsl:template>

</xsl:stylesheet>
