// *****************************************************************************
// * IBM MQSeries Workflow XML Sample Scenario                                 *
// *****************************************************************************
//
//  Licensed Materials - Property of IBM
//  5697-FM3 5655-A96
//  (C) Copyright IBM Corp. 1999-2000
//  US Government Users Restricted Rights - Use, duplication or
//  disclosure restricted by GSA ADP Schedule Contract
//  with IBM Corp.
//
// *****************************************************************************
// *****************************************************************************
//  DISCLAIMER
//  ----------
//  This material contains programming source code for your consideration.
//  These examples have not been thoroughly tested under all conditions.
//  IBM, therefore, cannot guarantee or imply reliability, serviceability,
//  or function of these programs.
//  ALL PROGRAMS CONTAINED HEREIN ARE PROVIDED TO YOU "AS IS", WITHOUT ANY
//  WARRANTIES (EXPRESS OR IMPLIED) OR SUPPORT WHATSOEVER, INCLUDING BUT
//  NOT LIMITED TO ANY IMPLIED WARRANTIES OF MERCHANTABILITY OR FITNESS
//  FOR A PARTICULAR PURPOSE.
// *****************************************************************************
package com.ibm.workflow.sample.xml;

import com.ibm.workflow.upes.Tracer;
import java.lang.Integer;
import java.lang.Runnable;
import java.lang.Thread;
import sun.io.ByteToCharUnicode;
import com.ibm.www.workflow.schema.*;
import samples.CreditRequest.*;
import org.apache.soap.*;

/************************************************************
 * The <b>CreditRequest</b> class represents a client application
 * which can execute credit approval processes.
 * It contains member fields describing the first, last name and
 * address of the customer for who the credit approval is requested.
 * Furthermore it contains the credit amount.
 * With <b>generateExecuteRequest</b> an XML message is contructed 
 * in which the given information is put in. It is used by <b>processCreditRequest</b>
 * to process a request.
 * This class provides a log for logging certain steps of the processing.
 * Especially for logging the outgoing and incoming messages.
 *
 * This application gets its input from the 'CreditRequestClient' queue which is managed
 * by the same queue mangager as the XML input queue of the execution manager to which
 * the request is sent to. (This is only for the ease of the example).
 *
 *
 * @version 0.0.1 (alpha)
 *
 ***********************************************************/
public class CreditRequest 
{
    private String _FirstName;
    private String _LastName;
    private String _Address;
    private int _PID;
    private int _CreditAmount;
    private Thread _t;
    private String _Log;

    private String _ReceiveFromQName = "CreditRequestClient";
    private String fieldLog = new String();
    protected transient java.beans.PropertyChangeSupport propertyChange;
    /*************************************************************************************
     * <b>CreditRequest</b> is the empty contructor of the class.
     *************************************************************************************/
    public CreditRequest()
    {
    }

    public synchronized void addPropertyChangeListener(java.beans.PropertyChangeListener listener)
    {
        getPropertyChange().addPropertyChangeListener(listener);
    }
    /*****************************************************************************
     * <b>appendLog</b> appends a log entry to the end of the log.
     * @parameters <b>append</b> the entry which is to be appended to the end
     * 
     *****************************************************************************/
    public void appendLog(String appendString)
    {
        setLog(getLog()+appendString+"\n");
    }
    public void firePropertyChange(String propertyName, Object oldValue, Object newValue)
    {
        getPropertyChange().firePropertyChange(propertyName, oldValue, newValue);
    }
    public String getAddress()
    {
        return _Address;
    }
    public int getCreditAmount()
    {
        return _CreditAmount;
    }
    public String getFirstName()
    {
        return _FirstName;
    }
    public String getLastName()
    {
        return _LastName;
    }
    public String getLog()
    {
        return fieldLog;
    }
    public int getPID()
    {
        return _PID;
    }
    protected java.beans.PropertyChangeSupport getPropertyChange()
    {
        if(propertyChange == null)
        {
            propertyChange = new java.beans.PropertyChangeSupport(this);
        };
        return propertyChange;
    }
    public static void main(String[] args)
    {
    }
    /*****************************************************************************
    * <b>processCreditRequest</b> is the method to process an execute process 
    * of MQSeries Workflow for the credit request process.
    * First the message is constructed by the <b>generateExecuteRequest</b> method.
    * Then a connection to the queuing system is established and the message is sent.
    * Afterwards it waits for a response with the <b>WaitForResponse</b> method which
    * opens an own thread for it.
    *
    * @see WaitForResponse
    * @see generateExecuteRequest
    * 
    *****************************************************************************/
    public void processCreditRequest()
    {
        appendLog("Processing CreditRequest for:");


        try
        {
          PersonInfo  pi = new PersonInfo( _FirstName.trim(),
                                           _LastName.trim());

          appendLog("Name     : " + _FirstName.trim() + " " + _LastName.trim() );
          appendLog("Address  : " + _Address.trim() );
          appendLog("Amount   : " + Long.toString(_CreditAmount) );

          CreditInfo  ci = new CreditInfo( pi,
                                           _Address.trim(),
                                           null,
                                           null,
                                           _CreditAmount);

          CreditRequestProxy testProxy = new CreditRequestProxy();

          CreditInfo ciRes = testProxy.CreditRequest( ci);
          appendLog( "Credit has been approved (Y|N): " + ciRes.AddApproval_Elem);
        }
        catch( SOAPException fault)
        {
          appendLog ("Ouch, the call failed: ");
          appendLog ("  Fault Code   = " + fault.getFaultCode ());  
          appendLog ("  Fault String = " + fault.getMessage ());
        }
        catch( Exception e)
        {
          appendLog ("Exception occured: " + e.getMessage());
        }
    }
    public synchronized void removePropertyChangeListener(java.beans.PropertyChangeListener listener)
    {
        getPropertyChange().removePropertyChangeListener(listener);
    }

    public void setAddress(String new_Address)
    {
        _Address = new_Address;
    }
    public void setCreditAmount(int newCreditAmount)
    {
        _CreditAmount = newCreditAmount;
    }
    public void setCreditAmount(String amountAsString)
    {
        /* Die Methode setCreditAmount ausfhren. */
        setCreditAmount(Integer.parseInt(amountAsString));
        return;
    }
    public void setFirstName(String newName)
    {
        _FirstName = newName;
    }
    public void setLastName(String new_lastName)
    {
        _LastName = new_lastName;
    }
    public void setLog(String log)
    {
        String oldValue = fieldLog;
        fieldLog = log;
        firePropertyChange("log", oldValue, log);
    }
    public void setPID(int new_PID)
    {
        _PID = new_PID;
    }
}

